@@ -20,9 +20,12 @@ The ID of the group.
 =cut
 
 has 'group_id'  => ( is => 'ro', isa => 'Str', required => 1 );
+has 'group_name' => ( is => 'ro', isa => 'Str', required => 1 );
 
 __PACKAGE__->meta->make_immutable();
 
+=back
+
 =head1 AUTHOR
 
 Jeff Kim <cpan@chosec.com>
@@ -35,4 +38,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
